@@ -49,7 +49,7 @@ gi.require_version("MatePanelApplet", "4.0")
 import os
 import sys
 import threading
-sys.path.insert(1, '/usr/lib/python3.6/site-packages')
+sys.path.insert(1, '/usr/lib/python3.7/site-packages')
 
 from Xlib.display import Display
 from Xlib import X, error
@@ -159,9 +159,9 @@ def applet_button_release(widget, event, the_dock):
             else:
 
                 # if the app only has a single window minimize or restore it, otherwise
-                # allow the user to select a window from a list
+                # perform the action specified by the user
                 if app.get_num_windows() == 1:
-                    the_dock.minimize_or_restore_windows(app, event)
+                    the_dock.minimize_or_restore_windows(app)
                 else:
                     the_dock.do_window_selection(app)
 
@@ -573,7 +573,7 @@ def applet_shortcut_handler(keybinder, the_dock):
             # if the app only has a single window minimize or restore it
             # otherwise scroll through all available windows
             if app.get_num_windows() == 1:
-                the_dock.minimize_or_restore_windows(app, None)
+                the_dock.minimize_or_restore_windows(app)
             else:
                 the_dock.do_window_scroll(Gdk.ScrollDirection.DOWN, 0, app)
 
