@@ -49,7 +49,8 @@ def write_xml(filename, desktop_files, light_ind, show_all_apps, multi_ind,
               use_dock_win_list, win_from_cur_ws_only,
               panel_change_color, dock_panel_change_only, use_panel_act_list,
               active_icon_bg, fallback_bar_col, spacing, attention_type,
-              popup_delay, saved_configs, pa_on_all_ws, dock_fixed_size):
+              popup_delay, saved_configs, pa_on_all_ws, dock_fixed_size,
+              click_action):
     """ Write the xml file using the specified information
 
     The xml file will be in e.g. the following format:
@@ -119,6 +120,8 @@ def write_xml(filename, desktop_files, light_ind, show_all_apps, multi_ind,
                                  only the workspace where they were pinned
 
         dock_fixed_size : the fixed size (if any) that the dock is to maintain
+        click_action : what the applet does when a running app's icon is clicked
+
     Returns:
         Boolean - True if the file was written successfully, False otherwise
 
@@ -175,6 +178,8 @@ def write_xml(filename, desktop_files, light_ind, show_all_apps, multi_ind,
 
     dfs_el = ET.Element("dock_fixed_size", dfs="%d" %dock_fixed_size)
 
+    ct_el = ET.Element("click_action", ca="%d" %click_action)
+
     root.append(pa_el)
     root.append(ind_el)
     root.append(sa_el)
@@ -192,6 +197,7 @@ def write_xml(filename, desktop_files, light_ind, show_all_apps, multi_ind,
     root.append(sc_el)
     root.append(paoaws_el)
     root.append(dfs_el)
+    root.append(ct_el)
 
     try:
         ET.ElementTree(root).write(filename, xml_declaration=True)
@@ -230,6 +236,7 @@ def read_xml(filename):
             saving...
             a boolean - the pinned apps on all workspaces setting
             an int    - the fixed size (if any) of the dock
+            an int    - the type of action to perform when a running app's icon is clicked
 
     """
 
@@ -364,12 +371,18 @@ def read_xml(filename):
     else:
         dock_fixed_size = -1  # the dock has no fixed size
 
+    ct_el = root.find("click_action")
+    if ct_el is not None:
+        click_action = int(ct_el.get("ca"))
+    else:
+        click_action = 0
+
     return [True, df_list, light_ind, show_all, multi_ind,
             use_win_list, win_from_cur_ws_only,
             panel_change_color, dock_panel_change_only,
             use_panel_act_list, bg_type, fallback_bar_col,
             spacing, attention_type, popup_delay, saved_configs,
-            pinned_apps_all_workspaces, dock_fixed_size]
+            pinned_apps_all_workspaces, dock_fixed_size, click_action]
 
 
 def read_app_xml(filename):
